package com.persagy.apm.common.config;

import com.persagy.apm.common.exception.RpcException;
import com.persagy.apm.common.response.FeignResponseContent;
import com.persagy.apm.common.response.FeignResponseItem;
import com.persagy.apm.common.response.FeignResponseMsg;
import com.persagy.common.enums.ResponseCode;
import org.aspectj.lang.annotation.AfterReturning;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Pointcut;

/**
 * feign调用接口，如果接口返回了报错信息，将报错信息抛出
 *
 * @author lixing
 * @version V1.0 2021/3/24 4:55 下午
 **/
@Aspect
public class FeignExceptionHandler {

    @Pointcut("@within(org.springframework.cloud.openfeign.FeignClient)")
    private void pointCutMethod() {
    }

    @AfterReturning(pointcut = "pointCutMethod()", returning = "res")
    public void process(Object res) {
        String respCode = null;
        String resultMsg = null;
        if (res instanceof FeignResponseMsg) {
            FeignResponseMsg response = (FeignResponseMsg) res;
            respCode = response.getRespCode();
            resultMsg = response.getRespMsg();
        }

        if (res instanceof FeignResponseContent) {
            FeignResponseContent response = (FeignResponseContent) res;
            respCode = response.getRespCode();
            resultMsg = response.getRespMsg();
        }

        if (res instanceof FeignResponseItem) {
            FeignResponseItem response = (FeignResponseItem) res;
            respCode = response.getRespCode();
            resultMsg = response.getRespMsg();
        }

        if (!ResponseCode.A00000.getCode().equals(respCode)) {
            throw new RpcException(resultMsg);
        }
    }
}
