package com.persagy.apm.common.response;

import com.fasterxml.jackson.annotation.JsonInclude;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import static com.persagy.common.enums.ResponseCode.A00000;

/**
 * 服务调用消息结果
 * @author Charlie Yu
 * @date 2021-03-25
 */
@Data
@JsonInclude(JsonInclude.Include.NON_NULL)
@ApiModel("响应结果")
public class CommonResult<T> {

    /** 不需要提示 */
    public static final CommonResult SUCCESS = new CommonResult();

    @ApiModelProperty(value = "响应码")
    private String respCode;
    @ApiModelProperty(value = "响应信息")
    private String respMsg;
    @ApiModelProperty(value = "响应数据")
    private T content;

    /**
     * 构造方法
     */
    public CommonResult(){
        this(A00000.getCode(), A00000.getDesc());
    }

    /**
     * 构造方法
     * @param respCode 响应码
     * @param respMsg 提示信息
     */
    public CommonResult(String respCode, String respMsg) {
        this(respCode, respMsg,null);
    }

    /**
     * 构造方法
     * @param respCode 响应码
     * @param respMsg 提示信息
     * @param content 数据
     */
    public CommonResult(String respCode, String respMsg, T content){
        this.respCode = respCode;
        this.respMsg = respMsg;
        this.content = content;
    }

    public static <T> CommonResult<T> success(T t) {
        return  new CommonResult<>(A00000.getCode(), A00000.getDesc(),t);
    }
}
