package com.persagy;

import cn.hutool.extra.spring.EnableSpringUtil;
import com.alibaba.druid.spring.boot.autoconfigure.DruidDataSourceAutoConfigure;
import com.persagy.log.annotation.EnableControllerLog;
import lombok.extern.slf4j.Slf4j;
import org.mybatis.spring.annotation.MapperScan;
import org.springframework.boot.Banner;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.cache.annotation.EnableCaching;
import org.springframework.cloud.client.discovery.EnableDiscoveryClient;
import org.springframework.cloud.openfeign.EnableFeignClients;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.EnableAspectJAutoProxy;
import org.springframework.scheduling.annotation.EnableScheduling;

/**
 * springboot服务器
 * 同时启动Eureka和Feign
 * @author Charlie Yu
 * @version 1.0 2021-03-02
 */
@EnableCaching(proxyTargetClass = true)
@EnableFeignClients(basePackages="com.persagy.apm.**.client")
@EnableControllerLog
@EnableDiscoveryClient
@Configuration
@EnableScheduling
@MapperScan(value = "com.persagy.apm.**.dao")
@EnableSpringUtil
@SpringBootApplication(exclude = DruidDataSourceAutoConfigure.class)
@EnableAspectJAutoProxy(exposeProxy = true)
@Slf4j
public class ServerApplication {

    public static void main(String[] args) {

        try {
            SpringApplication application = new SpringApplication(ServerApplication.class);
            application.setBannerMode(Banner.Mode.OFF);
            application.run(args);
        } catch (Exception e) {
            log.error("服务启动异常", e);
        }
    }
}
