package com.persagy.apm.translate.model;

import org.apache.commons.lang3.StringUtils;

import java.lang.annotation.*;

/**
 * 翻译描述信息注解
 * @author Charlie Yu
 * @Date 2021-03-03
 */
@Retention(RetentionPolicy.RUNTIME)
@Target({ElementType.METHOD,ElementType.ANNOTATION_TYPE})
@Inherited
@Documented
public @interface Trans {


    /**
     * 实体名称或表名或服务名,TransMeta中的source
     * @return 实体标识或表名或服务名
     */
    String source();


    /**
     * 翻译类型，涉及服务处理
     * @return 翻译类型
     */
    String type() default TransType.DB;

    /**
     * 参数字段(原始对象的使用的外键)
     */
    String parameter();


    /**
     * 查询结果字段名
     * @return 翻译结果标识
     */
    String result() default TransMeta.DEFAULT_RESULTFIELD;
    /**
     * 目标字段(原始对象的对应的翻译结果字段)
     * @return 翻译的目标字段
     */
    String target() default StringUtils.EMPTY;
    /**
     * 查询条件字段名
     */
    String condition() default TransMeta.DEFAULT_CONDITIONFIELD;


    /**
     * 多条结果时映射的字段,不是必须使用,批量查询结果映射键值字段
     * @return 批量查询结果映射键值字段
     */
    String mapKey() default StringUtils.EMPTY;

    /**
     * 是否为批量翻译，默认根据类型决定
     * @return 是否为批量查询
     */
    boolean batch() default false;
}
